@@ -25,7 +25,7 @@ class ClientProtocol(asyncio.Protocol):
     def data_received(self, data):
         if data == b"end":
             self.transport.close()
-        if data:
+        if data and not self.ins.future.done():
             self.ins.future.set_result(data)
         logger.debug("Data received: {!r}".format(data.decode()))
 
@@ -91,37 +91,3 @@ class WorkerClient:
         await cls.future
         cls._instance.transport.close()
 
-
-# async def async_main():
-#     m = WorkerClient("../unix_sock.sock")
-#     await m.create_conn() # 建立一个连接
-#     await m.send_msg("O", "hello")
-    
-#     await WorkerClient.send_msg(
-#         "U", [
-#             {
-#                 "key": "key",
-#                 "name": "name",
-#                 "status": "status",
-#                 "endTime": "endTime"
-#             }
-#         ]
-#     )
-#     await WorkerClient.send_msg(
-#         "H", {"header": "header"}
-#     )
-#     await WorkerClient.send_msg(
-#         "I", [
-#             {
-#                 "key": "key",
-#                 "name": "name",
-#             }
-#         ]
-#     )
-#     await WorkerClient.send_msg(
-#         "E", "xxxss"
-#     )
-#     await m.close()
-#     # await m.send_msg("O", "hello3")
-
-# asyncio.run(async_main())
