@@ -3,8 +3,8 @@
 # client protocol初始化连接的时候发送的信息，信息符合Header协议。
 # MsgType代码：H
 # 内容样例：
-#  {'task_id':"XXXX"}
-# fields中key的取值为：'task_id'。
+#  {'header':"XXXX"}
+# fields中key的取值为：'header'。
 HEADER_META = [0x48, "H"]
 HEADER_INDEX = b"\x01\x00"
 HEADER_FIELD_MAP = {HEADER_INDEX: "header"}
@@ -38,10 +38,12 @@ SUBTASKUPDATE_META = [0x55, "U"]
 KEY_INDEX = b"\x01\x00"
 STATUS_INDEX = b"\x02\x00"
 ENDTIME_INDEX = b"\x03\x00"
+NAME_INDEX = b"\x04\x00"
 SUBTASKUPDATE_FIELD_MAP = {
     KEY_INDEX: "key",
     STATUS_INDEX: "status",
     ENDTIME_INDEX: "endTime",
+    NAME_INDEX: "name",
 }
 SUBTASKUPDATE_REVERSE_FIELD_MAP = {
     v: k for k, v in SUBTASKUPDATE_FIELD_MAP.items()
@@ -65,6 +67,6 @@ SUBTASKINIT_REVERSE_FIELD_MAP = {
     v: k for k, v in SUBTASKINIT_FIELD_MAP.items()
 }
 
-HEADER_PROTOCOL = sum([HEADER_META, SUBTASKUPDATE_META], [])
+HEADER_PROTOCOL = sum([HEADER_META], [])
 MESSAGE_PROTOCOL = sum([STDERR_META, STDOUT_META], [])
-DETAILLIST_PROTOCOL = sum([SUBTASKINIT_META], [])
+DETAILLIST_PROTOCOL = sum([SUBTASKINIT_META, SUBTASKUPDATE_META], [])
